Smoothers
=========

.. automodule:: stonesoup.smoother
    :no-members:

.. automodule:: stonesoup.smoother.base
    :show-inheritance:

Kalman
------

.. automodule:: stonesoup.smoother.kalman
    :show-inheritance:



